==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/cs_CZ.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Vaše nastavení bylo aktualizováno.",
"Activity" => "Aktivita",
"A file or folder has been <strong>shared</strong>" => "Soubor nebo složka byla <strong>nasdílena</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Ve sdílené složce byl <strong>vytvořen</strong> nový soubor nebo nová složka.",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Ve sdílené složce došlo ke <strong>změně</strong> souboru nebo složky.",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Ve sdílené složce byl <strong>smazán</strong> soubor nebo složka.",
"You created %1\$s" => "Byl vytvořen %1\$s",
"%2\$s created %1\$s" => "%2\$s vytvořil %1\$s",
"You changed %1\$s" => "Byl změněn %1\$s",
"%2\$s changed %1\$s" => "%2\$s změnil %1\$s",
"You deleted %1\$s" => "Byl smazán %1\$s",
"%2\$s deleted %1\$s" => "%2\$s smazal %1\$s",
"You shared %1\$s with %2\$s" => "Byl sdílen %1\$s s %2\$s",
"You shared %1\$s with group %2\$s" => "Byl sdílen %1\$s se skupinou %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s vám sdílel %1\$s",
"You shared %1\$s via link" => "%1\$s byl nasdílen přes odkaz",
"Activity notification" => "Upozornění na aktivity",
"All Activities" => "Všechny aktivity",
"Activities by you" => "Vaše aktivity",
"Activities by others" => "Aktivity ostatních",
"Shares" => "Sdílení",
"Files" => "Soubory",
"%s and %s" => "%s a %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s a <strong class=\"tooltip\" title=\"%s\">%n další</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n další</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n dalších</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s a %n další","%s a %n další","%s a %n dalších"),
"Hello %s," => "Ahoj %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Tento e-mail dostáváte, protože za uplynulou hodinu došlo v %s k těmto událostem",
"You are receiving this email because in the last day the following things happened at %s" => "Tento e-mail dostáváte, protože za poslední den došlo v %s k těmto událostem",
"You are receiving this email because in the last week the following things happened at %s" => "Tento e-mail dostáváte, protože za poslední týden došlo v %s k těmto událostem",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Zde uvidíte seznam událostí jakmile začnete používat váš %s.",
"No more events to load" => "Žádné další události k načtení",
"Enable RSS feed" => "Povolit RSS kanál",
"Notifications" => "Upozornění",
"Mail" => "Pošta",
"Stream" => "Proud",
"You need to set up your email address before you can receive notification emails." => "Pokud chcete dostávat upozornění e-mailem, musíte nejprve vyplnit vaši e-mailovou adresu.",
"Send emails:" => "Odeslat e-maily:",
"Hourly" => "Každou hodinu",
"Daily" => "Denně",
"Weekly" => "Týdně",
"Activity feed" => "Přehled aktivit",
"Personal activity feed for %s" => "Přehled aktivit uživatele %s"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/cs_CZ.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Vaše nastavení bylo aktualizováno.",
"Activity" => "Aktivita",
"A file or folder has been <strong>shared</strong>" => "Soubor nebo složka byla <strong>nasdílena</strong>",
"A new file or folder has been <strong>created</strong>" => "Byl <strong>vytvořen</strong> nový soubor nebo adresář",
"A file or folder has been <strong>changed</strong>" => "Soubor nebo adresář byl <strong>změněn</strong>",
"A file or folder has been <strong>deleted</strong>" => "Soubor nebo adresář byl <strong>vymazán</strong>",
"You created %1\$s" => "Byl vytvořen %1\$s",
"%2\$s created %1\$s" => "%2\$s vytvořil %1\$s",
"You changed %1\$s" => "Byl změněn %1\$s",
"%2\$s changed %1\$s" => "%2\$s změnil %1\$s",
"You deleted %1\$s" => "Byl smazán %1\$s",
"%2\$s deleted %1\$s" => "%2\$s smazal %1\$s",
"You shared %1\$s with %2\$s" => "Byl sdílen %1\$s s %2\$s",
"You shared %1\$s with group %2\$s" => "Byl sdílen %1\$s se skupinou %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s vám sdílel %1\$s",
"You shared %1\$s via link" => "%1\$s byl nasdílen přes odkaz",
"Activity notification" => "Upozornění na aktivity",
"All Activities" => "Všechny aktivity",
"Activities by you" => "Vaše aktivity",
"Activities by others" => "Aktivity ostatních",
"Shares" => "Sdílení",
"Files" => "Soubory",
"%s and %s" => "%s a %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s a <strong class=\"tooltip\" title=\"%s\">%n další</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n další</strong>","%s a <strong class=\"tooltip\" title=\"%s\">%n dalších</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s a %n další","%s a %n další","%s a %n dalších"),
"Hello %s," => "Ahoj %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Tento e-mail dostáváte, protože za uplynulou hodinu došlo v %s k těmto událostem",
"You are receiving this email because in the last day the following things happened at %s" => "Tento e-mail dostáváte, protože za poslední den došlo v %s k těmto událostem",
"You are receiving this email because in the last week the following things happened at %s" => "Tento e-mail dostáváte, protože za poslední týden došlo v %s k těmto událostem",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Zde uvidíte seznam událostí jakmile začnete používat váš %s.",
"No more events to load" => "Žádné další události k načtení",
"Enable RSS feed" => "Povolit RSS kanál",
"Notifications" => "Upozornění",
"Mail" => "Pošta",
"Stream" => "Proud",
"Notify about my own actions" => "Posílat oznámení o vlastních činnostech",
"You need to set up your email address before you can receive notification emails." => "Pokud chcete dostávat upozornění e-mailem, musíte nejprve vyplnit vaši e-mailovou adresu.",
"Send emails:" => "Odeslat e-maily:",
"Hourly" => "Každou hodinu",
"Daily" => "Denně",
"Weekly" => "Týdně",
"Activity feed" => "Přehled aktivit",
"Personal activity feed for %s" => "Přehled aktivit uživatele %s"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;";
